/**
 * Copyright (c) 2019-2024 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Alexander Rose <alexander.rose@weirdbyte.de>
 * @author Áron Samuel Kovács <aron.kovacs@mail.muni.cz>
 * @author Ludovic Autin <ludovic.autin@gmail.com>
 * @author Gianluca Tomasello <giagitom@gmail.com>
 */
import { WebGLContext } from '../../mol-gl/webgl/context';
import { ParamDefinition as PD } from '../../mol-util/param-definition';
import { RenderTarget } from '../../mol-gl/webgl/render-target';
import { DrawPass } from './draw';
import { ICamera } from '../../mol-canvas3d/camera';
import { Light } from '../../mol-gl/renderer';
import { PostprocessingProps } from './postprocessing';
export declare const ShadowParams: {
    steps: PD.Numeric;
    bias: PD.Numeric;
    maxDistance: PD.Numeric;
    tolerance: PD.Numeric;
};
export type ShadowProps = PD.Values<typeof ShadowParams>;
export declare class ShadowPass {
    readonly webgl: WebGLContext;
    readonly drawPass: DrawPass;
    static isEnabled(props: PostprocessingProps): boolean;
    readonly shadowsTarget: RenderTarget;
    private readonly shadowsRenderable;
    constructor(webgl: WebGLContext, drawPass: DrawPass, width: number, height: number);
    setSize(width: number, height: number): void;
    update(camera: ICamera, light: Light, props: ShadowProps): void;
    render(): void;
}
